#
# MOD.R - Modulus after division
#


##-----------------------------------------------------------------------------
mod <- function(x, y)
    x %% y

